
[__Klarenz__](https://en.wikipedia.org/wiki/Clarence_Barlow) (current release: __v1.2.2__) is a highly minimalist (the entire API consists of a single class `Part` and a main processor function `proc`!) and Pythonic package for compiling Lilypond sheet music.

For more information and examples please check the [Documentation](https://teymuri.github.io/klarenz-docs/).

# Contributing

If you wish to contribute your code to this repository, please consider the following points:
- Packaging
  - Ensure to update the `src/klarenz/version.py` file and run `python prebuild.py` (and push the changes!) before initiating the build-upload process for each release with:

    ```
    python -m build && twine upload dist/*
    ```

_This README is generated by `prebuild.py`. Never edit it directly by hand! Instead, modify the `readme` variable in the
pre-build file._
